<?php
/**
 * Hosting providers data for SEO Pro Stack
 *
 * @package SEO_Pro_Stack
 * @subpackage SEO_Pro_Stack/Admin/Settings/Data
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Define hosting providers
 * 
 * @return array Array of hosting providers with their details
 */
function wp_seoprostack_get_hosting_providers() {
    return array(
        'closte' => array(
            'name' => 'Closte',
            'description' => 'Managed WordPress hosting with advanced performance optimization and auto-scaling.',
            'features' => array(
                'Auto-scaling architecture',
                'Global CDN included',
                'Advanced caching',
                'Free SSL certificates'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://closte.com/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://closte.com/pricing'
                )
            )
        ),
        'cloudron' => array(
            'name' => 'Cloudron',
            'description' => 'Self-hosted platform that makes it easy to run web applications like WordPress on your server.',
            'features' => array(
                'One-click installation',
                'Automatic updates',
                'Built-in backups',
                'SSL certificate management'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.cloudron.io/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://www.cloudron.io/pricing.html'
                )
            )
        ),
        'hostinger' => array(
            'name' => 'Hostinger',
            'description' => 'Affordable WordPress hosting with good performance and user-friendly management tools.',
            'features' => array(
                'Free domain name',
                'Managed WordPress features',
                'LiteSpeed cache',
                'Weekly backups'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.hostinger.com/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://www.hostinger.com/wordpress-hosting'
                )
            )
        ),
        'hetzner' => array(
            'name' => 'Hetzner Cloud',
            'description' => 'High-performance cloud servers with excellent price-to-performance ratio for self-managed WordPress hosting.',
            'features' => array(
                'Scalable cloud instances',
                'Per-minute billing',
                'Snapshots and backups',
                'Global data centers'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.hetzner.com/cloud/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://www.hetzner.com/cloud#pricing'
                )
            )
        ),
        'simplehost' => array(
            'name' => 'SimpleHost',
            'description' => 'Streamlined WordPress hosting with a focus on simplicity and performance.',
            'features' => array(
                'Simplified hosting dashboard',
                'Pre-optimized WordPress',
                'Automated backups',
                'Email hosting included'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://simplehost.so/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://simplehost.so/#pricing'
                )
            )
        ),
        'cloudflare' => array(
            'name' => 'Cloudflare',
            'description' => 'Global cloud platform that provides CDN, security, and performance optimization services.',
            'features' => array(
                'Global CDN network',
                'DDoS protection',
                'Web application firewall',
                'Performance optimization'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.cloudflare.com/en-gb/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://www.cloudflare.com/en-gb/plans/'
                )
            )
        ),
        'spaceship' => array(
            'name' => 'Spaceship',
            'description' => 'Modern hosting platform with advanced features for WordPress sites.',
            'features' => array(
                'Advanced WordPress tools',
                'Optimized for speed',
                'Developer-friendly features',
                'Smart caching system'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.spaceship.com/',
                    'primary' => true
                )
            )
        ),
        '101domain' => array(
            'name' => '101Domain',
            'description' => 'Domain registration and management service with support for hundreds of TLDs.',
            'features' => array(
                'Extensive TLD selection',
                'Domain privacy protection',
                'Expert domain support',
                'Bulk domain management'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.101domain.com/',
                    'primary' => true
                )
            )
        ),
        'namecheap' => array(
            'name' => 'Namecheap',
            'description' => 'Domain registrar and web hosting provider with competitive pricing and good support.',
            'features' => array(
                'Free WhoisGuard protection',
                'Competitive domain pricing',
                'Reliable hosting services',
                'Excellent support'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.namecheap.com/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://www.namecheap.com/hosting/shared/'
                )
            )
        ),
        'updownio' => array(
            'name' => 'Updown.io',
            'description' => 'Simple and affordable website monitoring service with uptime checks and performance metrics.',
            'features' => array(
                'Real-time monitoring',
                'Performance metrics',
                'Notification alerts',
                'Detailed reports'
            ),
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://updown.io/',
                    'primary' => true
                ),
                array(
                    'text' => 'Pricing',
                    'url' => 'https://updown.io/pricing'
                )
            )
        )
    );
}

// Alias for backward compatibility with the old codebase
function wp_allstars_get_hosting_providers() {
    return wp_seoprostack_get_hosting_providers();
}