<?php
/**
 * Tools data for SEO Pro Stack
 *
 * @package SEO_Pro_Stack
 * @subpackage SEO_Pro_Stack/Admin/Settings/Data
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Define tools
 * 
 * @return array Array of tools with their details
 */
function wp_seoprostack_get_tools() {
    return array(
        'advise' => array(
            'name' => 'Advise.so',
            'description' => 'Website analytics and optimization tool for improving user experience and conversion rates.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://advise.so/',
                    'primary' => true
                )
            )
        ),
        'seoutils' => array(
            'name' => 'SEO Utils',
            'description' => 'Collection of SEO tools to analyze and improve website search engine optimization.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://seoutils.app/',
                    'primary' => true
                )
            )
        ),
        'dataforseo' => array(
            'name' => 'DataForSEO',
            'description' => 'API-based SEO data provider for rank tracking, keyword research and competitive analysis.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://dataforseo.com/',
                    'primary' => true
                )
            )
        ),
        'ahrefs' => array(
            'name' => 'Ahrefs',
            'description' => 'Comprehensive SEO toolset for backlink analysis, keyword research, and competitor research.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://ahrefs.com/',
                    'primary' => true
                )
            )
        ),
        'localrank' => array(
            'name' => 'LocalRank.so',
            'description' => 'Local SEO tool for tracking and improving local search rankings for businesses.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://localrank.so/',
                    'primary' => true
                )
            )
        ),
        'turnithuman' => array(
            'name' => 'Turn It Human',
            'description' => 'AI content humanizer that makes AI-generated content sound more natural and authentic.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://turnithuman.com/',
                    'primary' => true
                )
            )
        ),
        'searchconsole' => array(
            'name' => 'Google Search Console',
            'description' => 'Free tool from Google to monitor and troubleshoot your site\'s presence in Google Search results.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://search.google.com/search-console/about',
                    'primary' => true
                )
            )
        ),
        'bingwebmaster' => array(
            'name' => 'Bing Webmaster Tools',
            'description' => 'Free tool from Microsoft to help optimize your website for Bing search engine.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.bing.com/webmasters/about',
                    'primary' => true
                )
            )
        ),
        'fiverr' => array(
            'name' => 'Fiverr',
            'description' => 'Freelance services marketplace for businesses to find digital services including web development.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.fiverr.com/',
                    'primary' => true
                )
            )
        ),
        'legiit' => array(
            'name' => 'Legiit',
            'description' => 'Marketplace for digital marketing services including SEO, content writing, and web design.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://legiit.com/',
                    'primary' => true
                )
            )
        ),
        'openwebui' => array(
            'name' => 'Open WebUI',
            'description' => 'Open-source web interface for interacting with AI models and chatbots.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://openwebui.com/',
                    'primary' => true
                )
            )
        ),
        'nextcloud' => array(
            'name' => 'Nextcloud',
            'description' => 'Self-hosted productivity platform and file sync solution for secure collaboration.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://nextcloud.com/',
                    'primary' => true
                )
            )
        ),
        'enpass' => array(
            'name' => 'Enpass',
            'description' => 'Password manager that stores sensitive information locally on your device.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.enpass.io/',
                    'primary' => true
                )
            )
        ),
        'pdfstudio' => array(
            'name' => 'PDF Studio',
            'description' => 'Professional PDF editor with advanced features for creating and modifying PDF documents.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.qoppa.com/pdfstudio/',
                    'primary' => true
                )
            )
        ),
        'affinity' => array(
            'name' => 'Affinity',
            'description' => 'Professional creative software suite including Photo, Designer, and Publisher applications.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://affinity.serif.com/',
                    'primary' => true
                )
            )
        ),
        'urlmonitor' => array(
            'name' => 'URL Monitor',
            'description' => 'Website monitoring service that tracks uptime, performance, and alerts you to issues.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://urlmonitor.com/',
                    'primary' => true
                )
            )
        ),
        'speedyindex' => array(
            'name' => 'Speedy Index',
            'description' => 'Tool for monitoring website indexing speed and performance in search engines.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://en.speedyindex.com/',
                    'primary' => true
                )
            )
        ),
        'pagespeed' => array(
            'name' => 'PageSpeed Insights',
            'description' => 'Google tool that analyzes web page performance on mobile and desktop devices.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://pagespeed.web.dev/',
                    'primary' => true
                )
            )
        ),
        'windsurf' => array(
            'name' => 'Codeium Windsurf',
            'description' => 'AI-powered IDE with advanced code completion and generation capabilities.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://codeium.com/windsurf',
                    'primary' => true
                )
            )
        ),
        'lowfruits' => array(
            'name' => 'Low Fruits',
            'description' => 'SEO tool for finding low-competition keywords to target for faster ranking.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://lowfruits.io/',
                    'primary' => true
                )
            )
        ),
        'keysearch' => array(
            'name' => 'Keysearch',
            'description' => 'Affordable keyword research tool for finding valuable keywords for SEO.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.keysearch.co/',
                    'primary' => true
                )
            )
        ),
        'smartlead' => array(
            'name' => 'SmartLead',
            'description' => 'Email outreach platform for cold email campaigns and lead generation.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.smartlead.ai/',
                    'primary' => true
                )
            )
        ),
        'zerogptplus' => array(
            'name' => 'ZeroGPT Plus',
            'description' => 'Advanced AI content detector with improved accuracy and additional features.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.zerogpt.plus/en',
                    'primary' => true
                )
            )
        ),
        'neuronwriter' => array(
            'name' => 'NeuronWriter',
            'description' => 'AI-powered SEO content optimization tool for creating high-ranking content.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.neuronwriter.com/',
                    'primary' => true
                )
            )
        ),
        'serposcope' => array(
            'name' => 'Serposcope',
            'description' => 'Open-source rank tracker to monitor website positions in search engines.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.serposcope.com/en/',
                    'primary' => true
                )
            )
        ),
        'seoptimer' => array(
            'name' => 'SEOptimer',
            'description' => 'Website audit tool that provides SEO, usability, and performance recommendations.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.seoptimer.com/',
                    'primary' => true
                )
            )
        ),
        'jitsi' => array(
            'name' => 'Jitsi Meet',
            'description' => 'Free, open-source video conferencing platform with no account required.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://meet.jit.si/',
                    'primary' => true
                )
            )
        ),
        'libreoffice' => array(
            'name' => 'LibreOffice',
            'description' => 'Free and open-source office suite compatible with Microsoft Office formats.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://www.libreoffice.org/',
                    'primary' => true
                )
            )
        ),
        'localwp' => array(
            'name' => 'Local',
            'description' => 'Local WordPress development tool for creating WordPress sites locally.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://localwp.com/',
                    'primary' => true
                )
            )
        ),
        'notability' => array(
            'name' => 'Notability',
            'description' => 'Note-taking app for iPad and Mac with handwriting and PDF annotation features.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://notability.com/',
                    'primary' => true
                )
            )
        ),
        'ulysses' => array(
            'name' => 'Ulysses',
            'description' => 'Writing app for Mac, iPad, and iPhone with a clean interface and powerful features.',
            'button_group' => array(
                array(
                    'text' => 'Home Page',
                    'url' => 'https://ulysses.app/',
                    'primary' => true
                )
            )
        ),
    );
}

// Alias for backward compatibility with the old codebase
function wp_allstars_get_tools() {
    return wp_seoprostack_get_tools();
}

// Alias for backward compatibility with the new codebase
function seoprostack_get_tools() {
    return wp_seoprostack_get_tools();
}