<?php
/**
 * The Theme tab for plugin settings.
 *
 * @package SEO_Pro_Stack
 * @subpackage SEO_Pro_Stack/Admin/Settings/Tabs
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * The Theme tab for plugin settings.
 */
class SEOProStack_Tab_Theme {

    /**
     * Render the tab content.
     */
    public function render() {
        // Get current theme
        $current_theme = wp_get_theme();
        ?>
        <div class="seoprostack-settings-content tab-content" id="theme">
            <div class="seoprostack-setting-section">
                <h2><?php esc_html_e('Theme Recommendations', 'seoprostack'); ?></h2>
                <p class="description"><?php esc_html_e('These themes are fast, SEO-friendly, and work well with SEO Pro Stack.', 'seoprostack'); ?></p>
                
                <div class="seoprostack-theme-info">
                    <h3><?php esc_html_e('Your Current Theme', 'seoprostack'); ?></h3>
                    <div class="seoprostack-current-theme">
                        <?php if ($current_theme->get_screenshot()) : ?>
                            <div class="seoprostack-theme-screenshot">
                                <img src="<?php echo esc_url($current_theme->get_screenshot()); ?>" alt="<?php echo esc_attr($current_theme->display('Name')); ?>">
                            </div>
                        <?php endif; ?>
                        <div class="seoprostack-theme-details">
                            <h4><?php echo esc_html($current_theme->display('Name')); ?></h4>
                            <div class="seoprostack-theme-version"><?php printf(esc_html__('Version: %s', 'seoprostack'), $current_theme->display('Version')); ?></div>
                            <div class="seoprostack-theme-author"><?php printf(esc_html__('By %s', 'seoprostack'), $current_theme->display('Author')); ?></div>
                            <p class="description"><?php echo esc_html($current_theme->display('Description')); ?></p>
                        </div>
                    </div>
                </div>
                
                <div class="seoprostack-recommended-themes">
                    <h3><?php esc_html_e('Recommended Themes', 'seoprostack'); ?></h3>
                    <div class="seoprostack-theme-grid">
                        <!-- Astra Theme -->
                        <div class="seoprostack-theme-card">
                            <div class="seoprostack-theme-card-header">
                                <img src="<?php echo esc_url(SEOPROSTACK_PLUGIN_URL . 'admin/images/themes/astra.jpg'); ?>" alt="Astra Theme">
                            </div>
                            <div class="seoprostack-theme-card-content">
                                <h4>Astra</h4>
                                <p><?php esc_html_e('Fast, lightweight and customizable WordPress theme suitable for blogs, personal portfolios and business websites.', 'seoprostack'); ?></p>
                                <a href="https://wpastra.com/" class="button" target="_blank"><?php esc_html_e('Learn More', 'seoprostack'); ?></a>
                            </div>
                        </div>
                        
                        <!-- GeneratePress Theme -->
                        <div class="seoprostack-theme-card">
                            <div class="seoprostack-theme-card-header">
                                <img src="<?php echo esc_url(SEOPROSTACK_PLUGIN_URL . 'admin/images/themes/generatepress.jpg'); ?>" alt="GeneratePress Theme">
                            </div>
                            <div class="seoprostack-theme-card-content">
                                <h4>GeneratePress</h4>
                                <p><?php esc_html_e('Lightweight WordPress theme focused on speed, stability, and accessibility.', 'seoprostack'); ?></p>
                                <a href="https://generatepress.com/" class="button" target="_blank"><?php esc_html_e('Learn More', 'seoprostack'); ?></a>
                            </div>
                        </div>
                        
                        <!-- Kadence Theme -->
                        <div class="seoprostack-theme-card">
                            <div class="seoprostack-theme-card-header">
                                <img src="<?php echo esc_url(SEOPROSTACK_PLUGIN_URL . 'admin/images/themes/kadence.jpg'); ?>" alt="Kadence Theme">
                            </div>
                            <div class="seoprostack-theme-card-content">
                                <h4>Kadence</h4>
                                <p><?php esc_html_e('Fast, lightweight, and extremely customizable WordPress theme.', 'seoprostack'); ?></p>
                                <a href="https://www.kadencewp.com/kadence-theme/" class="button" target="_blank"><?php esc_html_e('Learn More', 'seoprostack'); ?></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}